@@ -45,6 +45,7 @@
 #include "hooks.h"
 #include "uevent.h"
 #include "crash.h"
+#include "release.h"
 #include "trayappletui.h"
 
 /* some prototypes */
@@ -66,11 +67,18 @@ static gboolean FORCE_PKEXEC=FALSE;
 // delay on startup (to make session startup faster)
 static int STARTUP_DELAY=1;
 
+// make the release upgrader check for a devel release
+gboolean DEVEL_RELEASE=FALSE;
+
+// force release check
+static gboolean FORCE_RELEASE_CHECK=FALSE;
+
 // global debug options
 static gboolean HOOK_DEBUG = FALSE;
 static gboolean UPDATE_DEBUG = FALSE;
 static gboolean INOTIFY_DEBUG = FALSE;
 static gboolean UEVENT_DEBUG = FALSE;
+static gboolean RELEASE_DEBUG = FALSE;
 static gboolean MISC_DEBUG = FALSE;
 
 // logging stuff
@@ -95,6 +103,10 @@ static void debug_log_handler (const gchar   *log_domain,
       if (UEVENT_DEBUG)
          g_log_default_handler (log_domain, log_level, message, user_data);
    }
+   else if (log_domain && strcmp(log_domain, "release") == 0) {
+      if (RELEASE_DEBUG)
+         g_log_default_handler (log_domain, log_level, message, user_data);
+   }
    else if (MISC_DEBUG)
       g_log_default_handler (log_domain, log_level, message, user_data);
 }
@@ -524,10 +536,13 @@ static GOptionEntry entries[] =
    { "debug-updates", 0, 0, G_OPTION_ARG_NONE, &UPDATE_DEBUG, "Enable updates/autolaunch debugging"},
    { "debug-inotify", 0, 0, G_OPTION_ARG_NONE, &INOTIFY_DEBUG, "Enable inotify debugging"},
    { "debug-uevent", 0, 0, G_OPTION_ARG_NONE, &UEVENT_DEBUG, "Enable uevent debugging"},
+   { "debug-new-release-check", 0, 0, G_OPTION_ARG_NONE, &RELEASE_DEBUG, "Enable new release check debugging"},
    { "debug-misc", 0, 0, G_OPTION_ARG_NONE, &MISC_DEBUG, "Enable uncategorized debug prints"},
    { "force", 0, 0, G_OPTION_ARG_NONE, &FORCE_START, "Force start even if the user is not in the admin group"},
    { "force-use-pkexec", 0, 0, G_OPTION_ARG_NONE, &FORCE_PKEXEC, "Force running all commands (update-manager, synaptic) with pkexec" },
    { "startup-delay", 0, 0, G_OPTION_ARG_INT, &STARTUP_DELAY, "Delay startup by given amount of seconds" },
+   { "devel-release", 0, 0, G_OPTION_ARG_NONE, &DEVEL_RELEASE, "Make the release checker check for a new development release" },
+   { "force-release-check", 0, 0, G_OPTION_ARG_NONE, &FORCE_RELEASE_CHECK, "Force release check" },
    { NULL }
 };
 
@@ -554,7 +569,7 @@ main (int argc, char **argv)
         textdomain(GETTEXT_PACKAGE);
 
 	if (HOOK_DEBUG || UPDATE_DEBUG || INOTIFY_DEBUG ||
-	    UEVENT_DEBUG || MISC_DEBUG)
+	    UEVENT_DEBUG || RELEASE_DEBUG || MISC_DEBUG)
 		g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
 
 	// setup a custom debug log handler
@@ -566,6 +581,8 @@ main (int argc, char **argv)
 			   debug_log_handler, NULL);
 	g_log_set_handler ("uevent", G_LOG_LEVEL_DEBUG,
 			   debug_log_handler, NULL);
+	g_log_set_handler ("release", G_LOG_LEVEL_DEBUG,
+ 			   debug_log_handler, NULL);
 	g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG,
 			   debug_log_handler, NULL);
 
@@ -584,6 +601,10 @@ main (int argc, char **argv)
 	   exit(0);
 	}
 
+	// do not run as system user (e.g. guest user)
+	if (FORCE_RELEASE_CHECK)
+	   g_settings_reset(un->settings, SETTINGS_KEY_LAST_RELEASE_CHECK);
+
 	// check if it is running already
 	lockfn = g_build_filename (g_get_user_runtime_dir (), "update-notifier.pid", NULL);
 	pid_file = open (lockfn, O_CREAT | O_RDWR, 0600);
@@ -606,6 +627,9 @@ main (int argc, char **argv)
 	g_timeout_add_seconds(STARTUP_DELAY,
 			      (GSourceFunc)(tray_icons_init), un);
 
+	// init release checker
+	release_checker_init(un);
+
 	// init uevent monitoring (printer support, etc.)
 #ifdef ENABLE_SCP
 	uevent_init();
