@@ -36,6 +36,7 @@
 #define SETTINGS_KEY_APPORT_NOTIFICATIONS "show-apport-crashes"
 #define SETTINGS_KEY_END_SYSTEM_UIDS "end-system-uids"
 #define SETTINGS_KEY_AUTO_LAUNCH_INTERVAL "regular-auto-launch-interval"
+#define SETTINGS_KEY_LAST_RELEASE_CHECK "release-check-time"
 
 #define SETTINGS_UM_SCHEMA "com.ubuntu.update-manager"
 #define SETTINGS_UM_KEY_LAST_LAUNCH "launch-time"
@@ -56,6 +57,10 @@
 // anacron(and friends) to update the system (2h)
 #define OUTDATED_NAG_WAIT 60*60*2
 
+// this is the script and the time to run the release-upgrades checker
+#define RELEASE_UPGRADE_CHECKER "/usr/lib/ubuntu-release-upgrader/check-new-release-gtk"
+#define RELEASE_UPGRADE_CHECK_WAIT 60*60*24*14
+
 // cache-changed plugin dir
 #define CACHE_CHANGED_PLUGIN_DIR "/usr/share/update-notifier/plugins/cache-changed"
 
